==> haskell-deque-0.4.4.1-68-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deque.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 deque
version:              0.4.4.1
visibility:           public
id:                   deque-0.4.4.1-8HCLfkZfa7hE6lAnLEStOu
key:                  deque-0.4.4.1-8HCLfkZfa7hE6lAnLEStOu
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/deque
synopsis:             Double-ended queues
description:
    Strict and lazy implementations of Double-Ended Queue (aka Dequeue or Deque)
    based on head-tail linked list.

category:             Data
abi:                  0ddbee1ad76796cd853e6584eebd8a76
exposed:              True
exposed-modules:
    Deque.Lazy Deque.Lazy.Reader Deque.Lazy.State Deque.Strict
    Deque.Strict.Reader Deque.Strict.State

hidden-modules:       Deque.Lazy.Defs Deque.Prelude Deque.Strict.Defs
import-dirs:          /usr/lib/ghc-9.4.8/site-local/deque-0.4.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/deque-0.4.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/deque-0.4.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deque
hs-libraries:         HSdeque-0.4.4.1-8HCLfkZfa7hE6lAnLEStOu
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.4.0-AtkYwZfsO44KEb9h1CQ6ig mtl-2.2.2
    strict-list-0.1.7.6-JlwFZ2tsq5UKQOaMSvhwra

haddock-interfaces:   /usr/share/doc/haskell-deque/html/deque.haddock
haddock-html:         /usr/share/doc/haskell-deque/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-deque-0.4.4.1-69-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deque.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 deque
version:              0.4.4.1
visibility:           public
id:                   deque-0.4.4.1-9NjZF7YlRFZHAlCJj6qCDE
key:                  deque-0.4.4.1-9NjZF7YlRFZHAlCJj6qCDE
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/deque
synopsis:             Double-ended queues
description:
    Strict and lazy implementations of Double-Ended Queue (aka Dequeue or Deque)
    based on head-tail linked list.

category:             Data
abi:                  bdb288ac69bed4d2c764d02468bd1b38
exposed:              True
exposed-modules:
    Deque.Lazy Deque.Lazy.Reader Deque.Lazy.State Deque.Strict
    Deque.Strict.Reader Deque.Strict.State

hidden-modules:       Deque.Lazy.Defs Deque.Prelude Deque.Strict.Defs
import-dirs:          /usr/lib/ghc-9.4.8/site-local/deque-0.4.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/deque-0.4.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/deque-0.4.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deque
hs-libraries:         HSdeque-0.4.4.1-9NjZF7YlRFZHAlCJj6qCDE
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.4.0-AtkYwZfsO44KEb9h1CQ6ig mtl-2.2.2
    strict-list-0.1.7.6-9rgojGI62zB9kyI3RSVg7l

haddock-interfaces:   /usr/share/doc/haskell-deque/html/deque.haddock
haddock-html:         /usr/share/doc/haskell-deque/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
